==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ContainerResourceMetricSourceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ContainerResourceMetricSourceBuilder extends ContainerResourceMetricSourceFluentImpl<ContainerResourceMetricSourceBuilder> implements VisitableBuilder<ContainerResourceMetricSource,ContainerResourceMetricSourceBuilder>{
  public ContainerResourceMetricSourceBuilder() {
    this(false);
  }
  public ContainerResourceMetricSourceBuilder(Boolean validationEnabled) {
    this(new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent,ContainerResourceMetricSource instance) {
    this(fluent, instance, false);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent,ContainerResourceMetricSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withContainer(instance.getContainer());
      fluent.withName(instance.getName());
      fluent.withTargetAverageUtilization(instance.getTargetAverageUtilization());
      fluent.withTargetAverageValue(instance.getTargetAverageValue());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSource instance) {
    this(instance,false);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withContainer(instance.getContainer());
      this.withName(instance.getName());
      this.withTargetAverageUtilization(instance.getTargetAverageUtilization());
      this.withTargetAverageValue(instance.getTargetAverageValue());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ContainerResourceMetricSourceFluent<?> fluent;
  Boolean validationEnabled;
  public ContainerResourceMetricSource build() {
    ContainerResourceMetricSource buildable = new ContainerResourceMetricSource(fluent.getContainer(),fluent.getName(),fluent.getTargetAverageUtilization(),fluent.getTargetAverageValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-autoscaling-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ContainerResourceMetricSourceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ContainerResourceMetricSourceBuilder extends ContainerResourceMetricSourceFluent<ContainerResourceMetricSourceBuilder> implements VisitableBuilder<ContainerResourceMetricSource,ContainerResourceMetricSourceBuilder>{
  public ContainerResourceMetricSourceBuilder() {
    this(false);
  }
  public ContainerResourceMetricSourceBuilder(Boolean validationEnabled) {
    this(new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent,ContainerResourceMetricSource instance) {
    this(fluent, instance, false);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSourceFluent<?> fluent,ContainerResourceMetricSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ContainerResourceMetricSource());

    if (instance != null) {
      fluent.withContainer(instance.getContainer());
      fluent.withName(instance.getName());
      fluent.withTargetAverageUtilization(instance.getTargetAverageUtilization());
      fluent.withTargetAverageValue(instance.getTargetAverageValue());
      fluent.withContainer(instance.getContainer());
      fluent.withName(instance.getName());
      fluent.withTargetAverageUtilization(instance.getTargetAverageUtilization());
      fluent.withTargetAverageValue(instance.getTargetAverageValue());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSource instance) {
    this(instance,false);
  }
  public ContainerResourceMetricSourceBuilder(ContainerResourceMetricSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ContainerResourceMetricSource());

    if (instance != null) {
      this.withContainer(instance.getContainer());
      this.withName(instance.getName());
      this.withTargetAverageUtilization(instance.getTargetAverageUtilization());
      this.withTargetAverageValue(instance.getTargetAverageValue());
      this.withContainer(instance.getContainer());
      this.withName(instance.getName());
      this.withTargetAverageUtilization(instance.getTargetAverageUtilization());
      this.withTargetAverageValue(instance.getTargetAverageValue());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ContainerResourceMetricSourceFluent<?> fluent;
  Boolean validationEnabled;
  public ContainerResourceMetricSource build() {
    ContainerResourceMetricSource buildable = new ContainerResourceMetricSource(fluent.getContainer(),fluent.getName(),fluent.getTargetAverageUtilization(),fluent.getTargetAverageValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
